==> elara-core-1.2-sources.jar: org/tools4j/elara/event/EventType.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.event;

public enum EventType {
    ;
    /** Default application event type if no other positive type value is provided. */
    public static final int APPLICATION = 0;
    /** Final event marking the completion of processing a command. */
    public static final int COMMIT = -1;
    /** Final event marking the rollback of processing a command. */
    public static final int ROLLBACK = -2;

    public static boolean isAdmin(final int value) {
        return value < 0;
    }

    public static boolean isApplication(final int value) {
        return value >= 0;
    }

    public static boolean isCommit(final int value) {
        return value == COMMIT;
    }

    public static boolean isRollback(final int value) {
        return value == ROLLBACK;
    }
}

==> elara-core-1.5-sources.jar: org/tools4j/elara/event/EventType.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.event;

import org.tools4j.elara.plugin.api.TypeRange;

public enum EventType {
    ;
    /** Default application event type if no other positive type value is provided. */
    public static final int APPLICATION = 0;
    /** Final event marking the completion of processing a command. */
    public static final int COMMIT = -1;
    /** Final event marking the rollback of processing a command. */
    public static final int ROLLBACK = -2;

    /** Max event type that is reserved for elara and elara plugins*/
    public static final int RESERVED_MAX = TypeRange.MAX_RESERVED_TYPE;
    /** Min event type that is reserved for elara and elara plugins*/
    public static final int RESERVED_MIN = TypeRange.MIN_RESERVED_TYPE;

    public static boolean isAdmin(final int value) {
        return value < 0;
    }

    public static boolean isApplication(final int value) {
        return value >= 0;
    }

}
